@@ -2,19 +2,21 @@ package Catmandu::Fix::lookup_in_store;
 
 use Catmandu::Sane;
 
-our $VERSION = '1.10';
+our $VERSION = '1.2020';
 
 use Catmandu;
+use Catmandu::Util::Path qw(as_path);
+use Catmandu::Util qw(is_value);
 use Moo;
 use namespace::clean;
 use Catmandu::Fix::Has;
 
-with 'Catmandu::Fix::Base';
+with 'Catmandu::Fix::Builder';
 
 has path       => (fix_arg => 1);
 has store_name => (fix_arg => 1);
 has bag_name   => (fix_opt => 1, init_arg => 'bag');
-has default    => (fix_opt => 1);
+has default    => (fix_opt => 1, predicate => 1);
 has delete     => (fix_opt => 1);
 has store_args => (fix_opt => 'collect');
 has store      => (is      => 'lazy', init_arg => undef);
@@ -32,50 +34,42 @@ sub _build_bag {
         : $self->store->bag;
 }
 
-sub emit {
-    my ($self, $fixer) = @_;
-    my $path    = $fixer->split_path($self->path);
-    my $key     = pop @$path;
-    my $bag_var = $fixer->capture($self->bag);
-    my $delete  = $self->delete;
-    my $default = $self->default;
+sub _build_fixer {
+    my ($self) = @_;
 
-    $fixer->emit_walk_path(
-        $fixer->var,
-        $path,
-        sub {
-            my $var = shift;
-            $fixer->emit_get_key(
-                $var, $key,
-                sub {
-                    my $val_var     = shift;
-                    my $val_index   = shift;
-                    my $bag_val_var = $fixer->generate_var;
-                    my $perl
-                        = "if (is_value(${val_var}) && defined(my ${bag_val_var} = ${bag_var}->get(${val_var}))) {"
-                        . "${val_var} = ${bag_val_var};" . "}";
-                    if ($delete) {
-                        $perl .= "else {";
-                        if (defined $val_index)
-                        { # wildcard: only delete the value where the lookup failed
-                            $perl .= "splice(\@{${var}}, ${val_index}--, 1);";
-                        }
-                        else {
-                            $perl .= $fixer->emit_delete_key($var, $key);
-                        }
-                        $perl .= "}";
-                    }
-                    elsif (defined $default) {
-                        $perl
-                            .= "else {"
-                            . "${val_var} = "
-                            . $fixer->emit_value($default) . ";" . "}";
-                    }
-                    $perl;
-                }
-            );
-        }
-    );
+    my $bag = $self->bag;
+    my $cb;
+
+    if ($self->delete) {
+        $cb = sub {
+            my $val = $_[0];
+            if (is_value($val) && defined($val = $bag->get($val))) {
+                return $val;
+            }
+            return undef, 1, 1;
+        };
+    }
+    elsif ($self->has_default) {
+        my $default = $self->default;
+        $cb = sub {
+            my $val = $_[0];
+            if (is_value($val) && defined($val = $bag->get($val))) {
+                return $val;
+            }
+            $default;
+        };
+    }
+    else {
+        $cb = sub {
+            my $val = $_[0];
+            if (is_value($val) && defined($val = $bag->get($val))) {
+                return $val;
+            }
+            return undef, 1, 0;
+        };
+    }
+
+    as_path($self->path)->updater($cb);
 }
 
 1;
@@ -103,6 +97,22 @@ by looking up its value in a store
    # Lookup in a MongoDB database, using the default bag and delete the foo.bar field when nothing found
    lookup_in_store(foo.bar, MongoDB, database_name: lookups, delete: 1)
 
+   # Or, a much faster option: use a named store in a catmandu.yml file
+   #
+   # store:
+   #  mydbi:
+   #    package: DBI
+   #    options:
+   #      data_source: "dbi:SQLite:path/data.sqlite"
+   #  mymongo:
+   #    package: MongoDB
+   #    options:
+   #      database_name: lookups
+   lookup_in_store(foo.bar, mydbi)
+   lookup_in_store(foo.bar, mymongo, bag: mydata)
+   lookup_in_store(foo.bar, mymongo, default: 'default value')
+   lookup_in_store(foo.bar, mymongo, delete: 1)
+
 =head1 DESCRIPTION
 
 =head2 lookup_in_store(PATH,STORE[,store_param: store_val, ...][,bag: bag_name][,delete:1][,default:value])
@@ -157,9 +167,25 @@ The resulting data will contain:
       en: water
       nl: water
 
+=head1 DATABASE CONNECTIONS
+
+For every call to a C<lookup_in_store> a new database connection is created. It
+is much more effient to used named stores in a C<catmandu.yml> file. This file
+needs to contain all the connection parameters to the database. E.g.
+
+    store:
+       mystore:
+         package: MongoDB
+         options:
+            database_name: mydata
+
+The  C<catmandu.yml> file should be available in the same directory as where the
+C<catmandu> command is executed. Or, this directory can be set with the C<-L> option:
+
+    $ catmandu -L /tmp/path convert ...
+
 =head1 SEE ALSO
 
 L<Catmandu::Fix>, L<Catmandu::Store> , L<Catmandu::Fix::add_to_store>
 
 =cut
-
