@@ -2,7 +2,7 @@ package Catmandu::Iterable;
 
 use Catmandu::Sane;
 
-our $VERSION = '1.2016';
+our $VERSION = '1.2020';
 
 use Catmandu::Util qw(
     is_number
@@ -22,6 +22,7 @@ use namespace::clean;
 # delay loading these because of circular dependency
 require Catmandu::Iterator;
 require Catmandu::ArrayIterator;
+require Catmandu;
 
 requires 'generator';
 
@@ -61,6 +62,11 @@ sub count {
     $n;
 }
 
+sub add_to {
+    my ($self, $exporter) = @_;
+    $exporter->add_many($self);
+}
+
 sub slice {
     my ($self, $start, $total) = @_;
     $start //= 0;
@@ -196,6 +202,12 @@ sub map {
     );
 }
 
+sub fix {
+    my $self  = shift;
+    my $fixer = Catmandu->fixer(@_);
+    $self->map(sub {$fixer->fix(shift)});
+}
+
 sub reduce {
     my $self     = shift;
     my $memo_set = @_ > 1;
@@ -613,6 +625,11 @@ Return all the items in the iterator as an array ref.
 
 Return the count of all the items in the iterator.
 
+=head2 add_to
+
+Add all items in the iterator to a L<Catmandu::Exporter>. Returns a true value
+when the exportwas successful or undef on error.
+
 =head3 LOOPING
 
 =head2 each(\&callback)
@@ -857,6 +874,10 @@ Returns a new iterator containing for each item the result of the callback. If
 the callback returns multiple or no items, the resulting iterator will grow or
 shrink.
 
+=head2 fix(...)
+
+Apply a L<Catmandu::Fix> to each item and return the result as new iterator.
+
 =head2 reduce([$start],\&callback)
 
 For each item in the iterator execute C<&callback($prev,$item)> where C<$prev> is the
